@@ -1,5 +1,5 @@
 package MARC::Moose::Formater::UnimarcToMarc21;
-$MARC::Moose::Formater::UnimarcToMarc21::VERSION = '1.0.31';
+$MARC::Moose::Formater::UnimarcToMarc21::VERSION = '1.0.32';
 # ABSTRACT: Convert biblio record from UNIMARC to MARC21
 use Moose;
 
@@ -1246,7 +1246,7 @@ override 'format' => sub {
 
     # Clean non-filing characters in all fields
     for my $field (@{$record->fields}) {
-        next if $field->tag lt '010';
+        next if ref $field eq 'MARC::Moose::Field::Control';
         for (@{$field->subf} ) {
             next if $_->[0] !~ /[a-z0-9]/;
             $_->[1] =~ s/\x08|\x09//g;
@@ -1272,7 +1272,7 @@ MARC::Moose::Formater::UnimarcToMarc21 - Convert biblio record from UNIMARC to M
 
 =head1 VERSION
 
-version 1.0.31
+version 1.0.32
 
 =head1 SYNOPSYS
 
