@@ -1,21 +1,23 @@
 package MARC::Moose::Reader::File::Isis;
 # ABSTRACT: A file reader for ISIS (DOS) encoded records
-$MARC::Moose::Reader::File::Isis::VERSION = '1.0.31';
+$MARC::Moose::Reader::File::Isis::VERSION = '1.0.32';
 use Moose;
 
 use Carp;
 use MARC::Moose::Record;
 use MARC::Moose::Parser::Isis;
 
-extends 'MARC::Moose::Reader::File';
+with 'MARC::Moose::Reader::File';
 
 
 
+has '+parser' => ( default => sub { MARC::Moose::Parser::Isis->new() } );
 
-override 'read' => sub {
+
+sub read {
     my $self = shift;
 
-    $self->SUPER::read();
+    $self->count( $self->count + 1 );
 
     my $fh = $self->fh;
     my $raw;
@@ -27,7 +29,7 @@ override 'read' => sub {
     return 0 unless $raw;
 
     return $self->parser->parse( $raw );
-};
+}
 
 __PACKAGE__->meta->make_immutable;
 
@@ -45,7 +47,7 @@ MARC::Moose::Reader::File::Isis - A file reader for ISIS (DOS) encoded records
 
 =head1 VERSION
 
-version 1.0.31
+version 1.0.32
 
 =head1 DESCRIPTION
 
